import numpy as np
import gym
from gym import spaces, Wrapper


class EnvWrapper(Wrapper):
    """
    Wrapper for a GoalEnv which overrides the observation space for Hindsight Experience Replay.

    :param env: (gym.GoalEnv) Environment.
    """

    def __init__(self, env: gym.GoalEnv):
        super(EnvWrapper, self).__init__(env)

        # new observation space with concatenated observation and (desired) goal
        low_values = np.concatenate(
            [env.observation_space['observation'].low, env.observation_space['desired_goal'].low])
        high_values = np.concatenate(
            [env.observation_space['observation'].high, env.observation_space['desired_goal'].high])
        self.observation_space = spaces.Box(low_values, high_values, dtype=np.float32)
